==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/NativeUICheckbox.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUICheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUICheckbox, _super);
    function NativeUICheckbox() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.at = null;
        return _this;
    }
    NativeUICheckbox.prototype.get_c = function () {
        return 6;
    };
    Object.defineProperty(NativeUICheckbox.prototype, "av", {
        get: function () {
            var a = this.o(4);
            return a;
        },
        set: function (a) {
            this.af(4, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "aw", {
        get: function () {
            var a = this.o(5);
            return a;
        },
        set: function (a) {
            this.af(5, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "ax", {
        get: function () {
            var a = this.o(15);
            return a;
        },
        set: function (a) {
            this.af(15, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "au", {
        get: function () {
            return this.at;
        },
        set: function (a) {
            var b = this.at;
            this.at = a;
            if (this.at != null) {
                this.x(2, this.at);
            }
            else {
                this.ad(2, b);
            }
        },
        enumerable: true,
        configurable: true
    });
    NativeUICheckbox.$t = markType(NativeUICheckbox, 'NativeUICheckbox', NativeUIComponent.$);
    return NativeUICheckbox;
}(NativeUIComponent));
export { NativeUICheckbox };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/NativeUICheckbox.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUICheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUICheckbox, _super);
    function NativeUICheckbox() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ay = null;
        return _this;
    }
    NativeUICheckbox.prototype.get_e = function () {
        return 6;
    };
    Object.defineProperty(NativeUICheckbox.prototype, "a0", {
        get: function () {
            var a = this.q(4);
            return a;
        },
        set: function (a) {
            this.ak(4, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "a1", {
        get: function () {
            var a = this.q(5);
            return a;
        },
        set: function (a) {
            this.ak(5, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "a2", {
        get: function () {
            var a = this.q(15);
            return a;
        },
        set: function (a) {
            this.ak(15, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUICheckbox.prototype, "az", {
        get: function () {
            return this.ay;
        },
        set: function (a) {
            var b = this.ay;
            this.ay = a;
            if (this.ay != null) {
                this.z(2, this.ay);
            }
            else {
                this.ai(2, b);
            }
        },
        enumerable: true,
        configurable: true
    });
    NativeUICheckbox.$t = markType(NativeUICheckbox, 'NativeUICheckbox', NativeUIComponent.$);
    return NativeUICheckbox;
}(NativeUIComponent));
export { NativeUICheckbox };
